package com.xunwang.servicebase.config;

import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2WebMvc;

@Configuration
@EnableSwagger2WebMvc
public class SwaggerConfig {

    @Value("${swagger.enable}")
    private boolean enable;

    private ApiInfo setApiInfo(String title, String version, String desc, Contact contact) {

        return new ApiInfoBuilder()
                .title(title)
                .description(desc)
                .version(version)
                .contact(contact)
                .build();
    }

    @Bean
    public Docket webApiConfig(){
        return new Docket(DocumentationType.SWAGGER_2)
                // 创建接口文档的具体信息
                .apiInfo(setApiInfo("家教后端接口文档", "0.0.1-SNAPSHOT", "微信小程序后端接口文档说明", new Contact("Long", "xxxx", "xxx@xx.com")))
                // 创建选择器，控制哪些接口被加入文档
                .select()
                // 指定@ApiOperation标注的接口被加入文档
                .apis(RequestHandlerSelectors.withMethodAnnotation(ApiOperation.class))
                .build();
    }

//    /**
//     * 用户认证中心
//     * @return
//     */
//    @Bean
//    public Docket UcenterApiConfig() {
//        return new Docket(DocumentationType.SWAGGER_2)
//                .apiInfo(setApiInfo("用户认证中心", "V0.1", "用户认证中心微服务接口文档", new Contact("Long", "xxxx", "xxx@xx.com")))
//                .enable(true)
//                .select()
//                .paths(PathSelectors.ant("/ucenter/**"))
//                .apis(RequestHandlerSelectors.basePackage("com.xunwang.ucenter.controller"))
//                .build()
//                .groupName("ucenter");
//    }
//
//    /**
//     * 教育微服务
//     * @return
//     */
//    @Bean
//    public Docket EduApiConfig() {
//        return new Docket(DocumentationType.SWAGGER_2)
//                .apiInfo(setApiInfo("教育微服务", "V0.1", "教育微服务接口文档", new Contact("Long", "xxxx", "xxx@xx.com")))
//                .enable(enable)
//                .select()
//                .paths(PathSelectors.ant("/education/**"))
//                .apis(RequestHandlerSelectors.basePackage("com.xunwang.education.controller"))
//                .build()
//                .groupName("education");
//    }
//
//    /**
//     * 文件微服务
//     * @return
//     */
//    @Bean
//    public Docket FileApiConfig() {
//        return new Docket(DocumentationType.SWAGGER_2)
//                .apiInfo(setApiInfo("文件微服务", "V0.1", "文件微服务接口文档", new Contact("Long", "xxxx", "xxx@xx.com")))
//                .enable(true)
//                .select()
//                .paths(PathSelectors.ant("/file/**"))
//                .apis(RequestHandlerSelectors.basePackage("com.xunwang.file.controller"))
//                .build()
//                .groupName("file");
//    }


}
